#include "oglwidget.h"
#include "mainwindow.h"
#include <QDebug>
#include <QString>
#include <stdio.h>
#include <GL/glu.h>

#include <QWheelEvent>
#include <QCursor>
#include <QMouseEvent>

#include <math.h>

float linewidth;
float lineheight;
float zoom;
float zoomh;
float zoomfactor = 100;
float leadin;
float circlediameter;
float circle_x_center;
float circle_y_center;

OGLWidget::OGLWidget(QWidget *parent)
    : QOpenGLWidget(parent)
{

}

OGLWidget::~OGLWidget()
{

}

void OGLWidget::initializeGL()
{
    glClearColor(0,0,0,1);
    glEnable(GL_DEPTH_TEST);
    glEnable(GL_LIGHT0);
    glEnable(GL_LIGHTING);
    glColorMaterial(GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE);
    glEnable(GL_COLOR_MATERIAL);
}

void OGLWidget::paintGL()
{
    // update the line drawing on the screen.
    QTimer *timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(update()));
    timer->start(10);                                       //start(1000) is update the screen every 1000ms or 1 seconde.
    // end timer function

    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    glBegin(GL_LINES);

    //the horizontal red line that appear's in the screen :
    glColor3f(1.0f, 0.0f, 0.0f);  //red color

    //zoom = linewidth;
    //zoomh = lineheight;

    //4 lines makes a rectangle :

    //lead in:
    glVertex2f((-linewidth/2)-leadin, (-lineheight/2)-leadin); glVertex2f(-linewidth/2, - lineheight/2);

    //xstart:                                                //xend:
    glVertex2f(-linewidth/2, -lineheight/2);                   glVertex2f(linewidth/2, -lineheight/2);
    glVertex2f(linewidth/2, -lineheight/2);                    glVertex2f(linewidth/2, lineheight/2);
    glVertex2f(linewidth/2, lineheight/2);                     glVertex2f(-linewidth/2, lineheight/2);
    glVertex2f(-linewidth/2, lineheight/2);                    glVertex2f(-linewidth/2, -lineheight/2);
    glEnd();

    //draw circle:
    //glColor3f(0.2, 0.3, 0.5);   //blue color
    glColor3f(1,1,0);           //yellow color
    float num_segments = 100;
    //float r = circlediameter;        //radius
    //float cx = 0;               //centerpoint x
    //float cy = 0;               //centerpoint y

    glBegin(GL_LINE_LOOP);

         for (int ii = 0; ii < num_segments; ii++)   {
             float theta = 2.0f * M_PI * float(ii) / float(num_segments);   //get the current angle
             float x = circlediameter * cosf(theta);                                     //calculate the x component
             float y = circlediameter * sinf(theta);                                     //calculate the y component
             glVertex2f(x + circle_x_center, y + circle_y_center);                                    //output vertex
    }
    glEnd();

    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();
    glOrtho(-zoomfactor, zoomfactor, -zoomfactor, zoomfactor, -1, 3.5);                   //glOrtho is for zoom in and zoom out.
}

void OGLWidget::resizeGL(int w, int h)
{
    //glViewport(0,0,w,h);
    //glMatrixMode(GL_PROJECTION);
    //glLoadIdentity();
    //glOrtho(-1, 1, -1, 1, -1.0, 3.5);  //glOrtho is for zoom in and zoom out.
    //glMatrixMode(GL_MODELVIEW);
    //glLoadIdentity();
}

void OGLWidget::wheelEvent(QWheelEvent *event)
{
    if(event->delta() >0){
        zoomfactor = zoomfactor + 5; qDebug() << "zoom out" << zoomfactor;
    }
    else if(zoomfactor > 0){
        zoomfactor = zoomfactor - 5; qDebug() << "zoom in" << zoomfactor;
    }
}

void OGLWidget::mousePressEvent(QMouseEvent *event)
{
    if(event->buttons()){qDebug() << "mouse event";}
    QPoint mouseposition = QCursor::pos();
    qDebug() << mouseposition;
}


























